/*---------------------------------------------------------------------\
|                                                                      |
|                     _     _   _   _     __     _                     |
|                    | |   | | | \_/ |   /  \   | |                    |
|                    | |   | | | |_| |  / /\ \  | |                    |
|                    | |__ | | | | | | / ____ \ | |__                  |
|                    |____||_| |_| |_|/ /    \ \|____|                 |
|                                                                      |
|                             runlevel library                          |
|                                                                      |
|                                         (C) SUSE Linux Products GmbH |
\----------------------------------------------------------------------/

  File:       config.h

  Author:     <Marius Tomaschewski>     <mt@suse.de>
  Maintainer: <Marius Tomaschewski>     <mt@suse.de>

  Purpose:

/-*/
/**
 * @file config.h
 * This is config file, where we declare the namespace
 * and compilation time definitions, like our version.
 */
#ifndef    runlevel_config_h
#define    runlevel_config_h

#include  <limal/config.h>


/**
 * LiMaL runlevel library version.
 */
#ifndef LIMAL_RUNLEVEL_LIB_VERSION
#define LIMAL_RUNLEVEL_LIB_VERSION		"1.4.2"
#endif


/**
 * LiMaL runlevel API/namespace version.
 */
#ifndef LIMAL_RUNLEVEL_API_VERSION
#define LIMAL_RUNLEVEL_API_VERSION		1
#endif


/**
 * LiMaL runlevel namespace definition
 * with appended API version number.
 */
#ifndef RUNLEVEL_NAMESPACE
#define RUNLEVEL_NAMESPACE \
	LIMAL_DEFINE_NAMESPACE(runlevel, LIMAL_RUNLEVEL_API_VERSION)
#endif /* RUNLEVEL_NAMESPACE */

/**
 * @namespace limal
 * @brief The main LiMaL namespace.
 */
/**
 * @namespace limal::runlevel
 * @brief The LiMaL runlevel library namespace.
 *
 * The limal::runlevel namespace is only a alias.
 * The real namespace is defined in the file config.h
 * file to a namespace with appended API version number.
 */
#ifdef    __cplusplus
namespace LIMAL_NAMESPACE
{
    namespace RUNLEVEL_NAMESPACE
    {
    }
    namespace runlevel = RUNLEVEL_NAMESPACE;
}
#endif /* __cplusplus */


#ifdef    __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * LiMaL runlevel lib version number function.
 * @returns library version string
 */
const char * limal_runlevel_lib_version();


/**
 * LiMaL runlevel API version number function.
 * @returns library API version number
 */
unsigned int limal_runlevel_api_version();

#ifdef    __cplusplus
}
#endif /* __cplusplus */


#endif /* runlevel_config_h  */

